<?php
/**
 * Moral functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Moral
 */

if ( ! function_exists( 'lawman_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function lawman_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Moral, use a find and replace
		 * to change 'lawman' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'lawman' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support( 'responsive-embeds' ); 

		add_theme_support( 'register_block_pattern' ); 

		add_theme_support( 'register_block_style' ); 
		
		add_image_size( 'lawman-home-blog', 400, 300, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'lawman' ),
			'social' => esc_html__( 'Social', 'lawman' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'lawman_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		add_theme_support( 'custom-header', array(
		        'default-image'      => '%s/assets/img/header-image.jpg',
		        'default-text-color' => '000',
		        'width'              => 1920,
		        'height'             => 1080,
		        'flex-width'         => true,
		        'flex-height'        => true,
		    ) );
		 // Register default headers.
		register_default_headers( array(
			'default-banner' => array(
				'url'           => '%s/assets/img/header-image.jpg',
				'thumbnail_url' => '%s/assets/img/header-image.jpg',
				'description'   => esc_html_x( 'Default Banner', 'Header image description', 'lawman' ),
			),

		) );

		// Add theme support for selective refresh for widgets.
		// add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
    	/*
    	 * This theme styles the visual editor to resemble the theme style,
    	 * specifically font, colors, and column width.
     	 */
    	add_editor_style( array( 'assets/css/editor-style.css', lawman_fonts_url() ) );

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'lawman' ),
		       	'shortName' => esc_html__( 'S', 'lawman' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'lawman' ),
		       	'shortName' => esc_html__( 'M', 'lawman' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'lawman' ),
		       	'shortName' => esc_html__( 'L', 'lawman' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'lawman' ),
		       	'shortName' => esc_html__( 'XL', 'lawman' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
	}
endif;
add_action( 'after_setup_theme', 'lawman_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function lawman_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'lawman_content_width', 900 );
}
add_action( 'after_setup_theme', 'lawman_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function lawman_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'lawman' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'lawman' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'lawman' ),
		'id'            => 'blog-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'lawman' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );


	for ( $i=1; $i <= 4; $i++ ) { 
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area ', 'lawman' )  . $i,
			'id'            => 'footer-' . $i,
			'description'   => esc_html__( 'Add widgets here.', 'lawman' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
}
add_action( 'widgets_init', 'lawman_widgets_init' );

/**
 * Register custom fonts.
 */
function lawman_fonts_url() {
	$fonts_url = '';

	$font_families = array();
	
	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Montserrat, translate this to 'off'. Do not translate
	 * into your own language.
	 */

	$muli = _x( 'on', 'Muli font: on or off', 'lawman' );

	if ( 'off' !== $muli ) {
		$font_families[] = 'Muli:400,700';
	}

	$oxygen = _x( 'on', 'Oxygen font: on or off', 'lawman' );

		if ( 'off' !== $oxygen ) {
		$font_families[] = 'Oxygen:400,700';
	}
	
	$playfair_display = _x( 'on', 'Playfair Display font: on or off', 'lawman' );

	if ( 'off' !== $playfair_display ) {
		$font_families[] = 'Playfair Display:400,700';
	}

	$libre_baskerville = _x( 'on', 'Libre Baskerville font: on or off', 'lawman' );

	if ( 'off' !== $libre_baskerville ) {
		$font_families[] = 'Open Baskerville:400,700';
	}

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);

	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function lawman_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'lawman-fonts', wptt_get_webfont_url( lawman_fonts_url() ), array(), null );
	
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', '', '5.13.1' );

	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/css/slick.css', '', '1.8.0' );

	wp_enqueue_style( 'slick-theme', get_template_directory_uri() . '/assets/css/slick-theme.css', '', '1.8.0' );

	// blocks
	wp_enqueue_style( 'lawman-blocks', get_template_directory_uri() . '/assets/css/blocks.css' );

	wp_enqueue_style( 'lawman-style', get_stylesheet_uri() );

	wp_enqueue_script( 'packery-pkgd', get_template_directory_uri(). '/assets/js/packery.pkgd.js', array( 'jquery' ), '20151215', true );
	
	wp_enqueue_script( 'isotope-pkgd', get_template_directory_uri(). '/assets/js/isotope.pkgd.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'slick-jquery', get_template_directory_uri(). '/assets/js/slick.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'lawman-navigation', get_template_directory_uri(). '/assets/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'lawman-skip-link-focus-fix', get_template_directory_uri(). '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'lawman-custom', get_template_directory_uri(). '/assets/js/custom.js', array( 'jquery' ), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'lawman_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since lawman 1.0.0
 */
function lawman_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'lawman-block-editor-style', get_template_directory_uri().'/assets/css/editor-blocks.css' );
	// Add custom fonts.
	wp_enqueue_style( 'lawman-fonts', wptt_get_webfont_url( lawman_fonts_url() ), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'lawman_block_editor_styles' );

/**
 * Custom template tags for this theme.
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_parent_theme_file_path( '/inc/template-functions.php' );

/**
 * Customizer additions.
 */
require get_parent_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

/**
 * Breadcrumb trail class.
 */
require get_parent_theme_file_path( '/inc/class-breadcrumb-trail.php' );

/**
 * Custom widget additions.
 */
require get_parent_theme_file_path( '/inc/widgets/widgets.php' );

/**
 * Metabox
 */
require get_parent_theme_file_path( '/inc/metabox.php' );

require get_parent_theme_file_path( '/inc/wptt-webfont-loader.php' );

/**
 * TGMPA call
 */
require get_parent_theme_file_path( '/inc/tgmpa/call.php' );


if ( class_exists( 'CatchThemesDemoImportPlugin' ) ) {
    /**
    * OCDI plugin demo importer compatibility.
    */
    require get_template_directory() . '/inc/demo-import.php';
}


/**
 * Styles the header image and text displayed on the blog.
 *
 * @see lawman_custom_header_setup().
 */
function lawman_header_text_style() {
	// If we get this far, we have custom styles. Let's do this.
	$header_text_display = get_theme_mod( 'lawman_header_text_display' );
	?>
	<style type="text/css">

	.site-title a{
		color: #<?php echo esc_attr(  get_theme_mod( 'header_textcolor', 'fff' ) ); ?>;
	}
	.site-description {
		color: <?php echo esc_attr( get_theme_mod( 'lawman_header_tagline', '#fff' ) ); ?>;
	}
	
	</style>
	<?php
}
add_action( 'wp_head', 'lawman_header_text_style' );

/**
 *
 * Reset all setting to default.
 *
 */
function lawman_reset_settings() {
    $reset_settings = get_theme_mod( 'lawman_reset_settings', false );
    if ( $reset_settings ) {
        remove_theme_mods();
    }
}
add_action( 'customize_save_after', 'lawman_reset_settings' );


if ( ! function_exists( 'lawman_exclude_sticky_posts' ) ) {
    function lawman_exclude_sticky_posts( $query ) {
        if ( ! is_admin() && $query->is_main_query() && $query->is_home() ) {
            $sticky_posts = get_option( 'sticky_posts' );  
            if ( ! empty( $sticky_posts ) ) {
            	$query->set('post__not_in', $sticky_posts );
            }
            $query->set('ignore_sticky_posts', true );
        }
    }
}
add_action( 'pre_get_posts', 'lawman_exclude_sticky_posts' );